import sys
from linkwiz.core import process_url


def main():
    """Entry point of the program."""
    if len(sys.argv) != 2:
        print("Usage: linkwiz [install | uninstall | <url>]")
        return

    arg = sys.argv[1]

    if arg == "install":
        print("Installing...")
    elif arg == "uninstall":
        print("Uninstalling...")
    else:
        process_url(arg)


if __name__ == "__main__":
    main()



import os
from typing import Dict
from tomlkit import parse, dumps
from tomlkit.toml_document import TOMLDocument
from xdg import BaseDirectory


class Config:
    def __init__(self, config_path: str = None):
        self.config_path = config_path or os.path.join(
            BaseDirectory.xdg_config_home, "linkwiz.toml"
        )
        self._config = self._load_config()

    def _load_config(self) -> TOMLDocument:
        """
        Load the configuration file, creating a new one with defaults if it doesn't exist.
        """
        if os.path.exists(self.config_path):
            with open(self.config_path, "r") as f:
                return parse(f.read())
        else:
            config = TOMLDocument()
            config.add("browsers", {})
            config.add("rules", {"regex": {}, "hostname": {}})
            with open(self.config_path, "w") as f:
                f.write(dumps(config))
            return config

    def save_config(self):
        """
        Save the configuration file.
        """
        with open(self.config_path, "w") as f:
            f.write(dumps(self._config))

    def add_rules(self, hostname: str, browser_name: str):
        """
        Add rules to the configuration file.
        """
        if "rules" not in self._config:
            self._config.add("rules", {"regex": {}, "hostname": {}})
        rules = self._config["rules"]
        if "hostname" not in rules:
            rules["hostname"] = {}
        rules["hostname"][hostname] = browser_name
        self.save_config()

    @property
    def browsers(self) -> Dict:
        """
        Get the browsers from the configuration.
        """
        return self._config.get("browsers", {})

    @property
    def rules(self) -> Dict:
        """
        Get the rules from the configuration.
        """
        return self._config.get("rules", {})

    @property
    def rules_regex(self) -> Dict:
        """
        Get the regex rules from the configuration.
        """
        return self.rules.get("regex", {})

    @property
    def rules_hostname(self) -> Dict:
        """
        Get the hostname rules from the configuration.
        """
        return self.rules.get("hostname", {})


config = Config()

custom_browsers = config.browsers
rules = config.rules
rules_regex = config.rules_regex
rules_hostname = config.rules_hostname



from urllib.parse import urlparse
from linkwiz.browser import get_installed_browsers
from linkwiz.match import find_matching_browser
from linkwiz.gui import LinkwizGUI
from linkwiz.launch import launch_browser
import logging


def process_url(url):
    """Process the provided URL."""
    parsed_url = urlparse(url)

    if parsed_url.scheme not in ("http", "https"):
        raise ValueError("Invalid URL.")

    browsers = get_installed_browsers()

    try:
        launch_browser_command = find_matching_browser(
            browsers, parsed_url.geturl(), parsed_url.hostname
        )
        if launch_browser_command:
            launch_browser(*launch_browser_command)
            return

        app = LinkwizGUI(browsers, url)
        launch_browser_command = app.run()
        launch_browser(*launch_browser_command)

    except Exception as e:
        logging.error(f"Error processing URL: {e}")
